# atelier-toolbox

![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/mihaichris/atelier-toolbox/build.yml)
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/mihaichris/atelier-toolbox/test.yml?label=test)
[![Issues](https://img.shields.io/github/issues/mihaichris/atelier-toolbox)](https://github.com/mihaichris/atelier-toolbox/issues)
[![License](https://img.shields.io/github/license/mihaichris/atelier-toolbox)](https://github.com/mihaichris/atelier-toolbox/blob/main/LICENSE)
[![Version](https://img.shields.io/github/v/tag/mihaichris/atelier-toolbox)](https://github.com/mihaichris/atelier-toolbox/blob/main/LICENSE)
[![Python Version](https://img.shields.io/pypi/pyversions/atelier-toolbox)](https://pypi.org/project/atelier-toolbox/)

## Description

Tools for various automations 🧰.

## Installation

You can install the Toolbox from [PyPI](https://pypi.org/):

```python
python -m pip install atelier-toolbox
```
The package is supported on Python 3.10 and above.


## How to use

```python
Usage: toolbox [OPTIONS] COMMAND [ARGS]...

╭─ Options ─────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────╮
│ --install-completion          Install completion for the current shell.                                                                                                                                   │
│ --show-completion             Show completion for the current shell, to copy it or customize the installation.                                                                                            │
│ --help                        Show this message and exit.                                                                                                                                                 │
╰───────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────╯
╭─ Commands ────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────╮
│ business                                                  Business CLI Tool                                                                                                                               │
│ dw                                                        Download CLI Tool                                                                                                                               │
│ hash                                                      Hashing Files CLI Tool                                                                                                                          │
│ pdf                                                       PDF CLI Tool                                                                                                                                    │
╰───────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────╯
```

## CHANGELOG
 Please refer to [CHANGELOG.md](https://github.com/mihaichris/toolbox/blob/main/CHANGELOG.md)

## License
[MIT](https://opensource.org/licenses/MIT)
